Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS App Runner.

Actions, resources, and condition keys for AWS App Runner - Service Authorization Reference

# Actions, resources, and condition keys for AWS App Runner

AWS App Runner (service prefix: `apprunner` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS App Runner
- Resource types defined by AWS App Runner
- Condition keys for AWS App Runner

## Actions defined by AWS App Runner

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AssociateCustomDomain | Grants permission to associate your own domain name with the AWS App Runner subdomain URL of your App Runner service | Write | service* |  |
AssociateWebAcl [permission only] | Grants permission to associate the service with an AWS WAF web ACL | Write | service* |  |
webacl* |  |
CreateAutoScalingConfiguration | Grants permission to create an AWS App Runner automatic scaling configuration resource | Write | autoscalingconfiguration* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateConnection | Grants permission to create an AWS App Runner connection resource | Write | connection* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateObservabilityConfiguration | Grants permission to create an AWS App Runner observability configuration resource | Write | observabilityconfiguration* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateService | Grants permission to create an AWS App Runner service resource | Write | service* |  |
autoscalingconfiguration |  |
connection |  |
observabilityconfiguration |  |
vpcconnector |  |
| aws:RequestTag/${TagKey} aws:TagKeys apprunner:ConnectionArn apprunner:AutoScalingConfigurationArn apprunner:ObservabilityConfigurationArn apprunner:VpcConnectorArn |
CreateVpcConnector | Grants permission to create an AWS App Runner VPC connector resource | Write | vpcconnector* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateVpcIngressConnection | Grants permission to create an AWS App Runner VpcIngressConnection resource | Write | vpcingressconnection* |  |
| aws:RequestTag/${TagKey} aws:TagKeys apprunner:ServiceArn apprunner:VpcId apprunner:VpcEndpointId |
DeleteAutoScalingConfiguration | Grants permission to delete an AWS App Runner automatic scaling configuration resource | Write | autoscalingconfiguration* |  |
DeleteConnection | Grants permission to delete an AWS App Runner connection resource | Write | connection* |  |
DeleteObservabilityConfiguration | Grants permission to delete an AWS App Runner observability configuration resource | Write | observabilityconfiguration* |  |
DeleteService | Grants permission to delete an AWS App Runner service resource | Write | service* |  |
DeleteVpcConnector | Grants permission to delete an AWS App Runner VPC connector resource | Write | vpcconnector* |  |
DeleteVpcIngressConnection | Grants permission to delete an AWS App Runner VpcIngressConnection resource | Write | vpcingressconnection* |  |
DescribeAutoScalingConfiguration | Grants permission to retrieve the description of an AWS App Runner automatic scaling configuration resource | Read | autoscalingconfiguration* |  |
DescribeCustomDomains | Grants permission to retrieve descriptions of custom domain names associated with an AWS App Runner service | Read | service* |  |
DescribeObservabilityConfiguration | Grants permission to retrieve the description of an AWS App Runner observability configuration resource | Read | observabilityconfiguration* |  |
DescribeOperation | Grants permission to retrieve the description of an operation that occurred on an AWS App Runner service | Read | service* |  |
DescribeService | Grants permission to retrieve the description of an AWS App Runner service resource | Read | service* |  |
DescribeVpcConnector | Grants permission to retrieve the description of an AWS App Runner VPC connector resource | Read | vpcconnector* |  |
DescribeVpcIngressConnection | Grants permission to retrieve the description of an AWS App Runner VpcIngressConnection resource | Read | vpcingressconnection* |  |
DescribeWebAclForService [permission only] | Grants permission to get the AWS WAF web ACL that is associated with an AWS App Runner service | Read | service* |  |
DisassociateCustomDomain | Grants permission to disassociate a custom domain name from an AWS App Runner service | Write | service* |  |
DisassociateWebAcl [permission only] | Grants permission to disassociate the service with an AWS WAF web ACL | Write | service* |  |
ListAssociatedServicesForWebAcl [permission only] | Grants permission to list the services that are associated with an AWS WAF web ACL | List | webacl* |  |
ListAutoScalingConfigurations | Grants permission to retrieve a list of AWS App Runner automatic scaling configurations in your AWS account | List |  |  |
ListConnections | Grants permission to retrieve a list of AWS App Runner connections in your AWS account | List |  |  |
ListObservabilityConfigurations | Grants permission to retrieve a list of AWS App Runner observability configurations in your AWS account | List |  |  |
ListOperations | Grants permission to retrieve a list of operations that occurred on an AWS App Runner service resource | List | service* |  |
ListServices | Grants permission to retrieve a list of running AWS App Runner services in your AWS account | List |  |  |
ListServicesForAutoScalingConfiguration | Grants permission to retrieve a list of associated AppRunner services of an AWS App Runner automatic scaling configuration in your AWS account | List | autoscalingconfiguration* |  |
ListTagsForResource | Grants permission to list tags associated with an AWS App Runner resource | Read | autoscalingconfiguration |  |
connection |  |
observabilityconfiguration |  |
service |  |
vpcconnector |  |
ListVpcConnectors | Grants permission to retrieve a list of AWS App Runner VPC connectors in your AWS account | List |  |  |
ListVpcIngressConnections | Grants permission to retrieve a list of AWS App Runner VpcIngressConnections in your AWS account | List |  |  |
PauseService | Grants permission to pause an active AWS App Runner service | Write | service* |  |
ResumeService | Grants permission to resume an active AWS App Runner service | Write | service* |  |
StartDeployment | Grants permission to initiate a manual deployemnt to an AWS App Runner service | Write | service* |  |
TagResource | Grants permission to add tags to, or update tag values of, an AWS App Runner resource | Tagging | autoscalingconfiguration |  |
connection |  |
observabilityconfiguration |  |
service |  |
vpcconnector |  |
vpcingressconnection |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to remove tags from an AWS App Runner resource | Tagging | autoscalingconfiguration |  |
connection |  |
observabilityconfiguration |  |
service |  |
vpcconnector |  |
vpcingressconnection |  |
| aws:TagKeys |
UpdateDefaultAutoScalingConfiguration | Grants permission to update an AWS App Runner automatic scaling configuration to be the default in your AWS account | Write | autoscalingconfiguration* |  |
UpdateService | Grants permission to update an AWS App Runner service resource | Write | service* |  |
autoscalingconfiguration |  |
connection |  |
observabilityconfiguration |  |
vpcconnector |  |
| apprunner:ConnectionArn apprunner:AutoScalingConfigurationArn apprunner:ObservabilityConfigurationArn apprunner:VpcConnectorArn |
UpdateVpcIngressConnection | Grants permission to update an AWS App Runner VpcIngressConnection resource | Write | vpcingressconnection* |  |
| apprunner:VpcId apprunner:VpcEndpointId |

## Resource types defined by AWS App Runner

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
service | `arn:$ { Partition}:apprunner:$ { Region}:$ { Account}:service/$ { ServiceName}/$ { ServiceId}` | aws:ResourceTag/${TagKey}
connection | `arn:$ { Partition}:apprunner:$ { Region}:$ { Account}:connection/$ { ConnectionName}/$ { ConnectionId}` | aws:ResourceTag/${TagKey}
autoscalingconfiguration | `arn:$ { Partition}:apprunner:$ { Region}:$ { Account}:autoscalingconfiguration/$ { AutoscalingConfigurationName}/$ { AutoscalingConfigurationVersion}/$ { AutoscalingConfigurationId}` | aws:ResourceTag/${TagKey}
observabilityconfiguration | `arn:$ { Partition}:apprunner:$ { Region}:$ { Account}:observabilityconfiguration/$ { ObservabilityConfigurationName}/$ { ObservabilityConfigurationVersion}/$ { ObservabilityConfigurationId}` | aws:ResourceTag/${TagKey}
vpcconnector | `arn:$ { Partition}:apprunner:$ { Region}:$ { Account}:vpcconnector/$ { VpcConnectorName}/$ { VpcConnectorVersion}/$ { VpcConnectorId}` | aws:ResourceTag/${TagKey}
vpcingressconnection | `arn:$ { Partition}:apprunner:$ { Region}:$ { Account}:vpcingressconnection/$ { VpcIngressConnectionName}/$ { VpcIngressConnectionId}` | aws:ResourceTag/${TagKey}
webacl | `arn:$ { Partition}:wafv2:$ { Region}:$ { Account}:$ { Scope}/webacl/$ { Name}/$ { Id}` |

## Condition keys for AWS App Runner

AWS App Runner defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
apprunner:AutoScalingConfigurationArn | Filters access by the CreateService and UpdateService actions based on the ARN of an associated AutoScalingConfiguration resource | ARN
apprunner:ConnectionArn | Filters access by the CreateService and UpdateService actions based on the ARN of an associated Connection resource | ARN
apprunner:ObservabilityConfigurationArn | Filters access by the CreateService and UpdateService actions based on the ARN of an associated ObservabilityConfiguration resource | ARN
apprunner:ServiceArn | Filters access by the CreateVpcIngressConnection action based on the ARN of an associated Service resource | ARN
apprunner:VpcConnectorArn | Filters access by the CreateService and UpdateService actions based on the ARN of an associated VpcConnector resource | ARN
apprunner:VpcEndpointId | Filters access by the CreateVpcIngressConnection and UpdateVpcIngressConnection actions based on the VPC Endpoint in the request | String
apprunner:VpcId | Filters access by the CreateVpcIngressConnection and UpdateVpcIngressConnection actions based on the VPC in the request | String
aws:RequestTag/${TagKey} | Filters access by actions based on the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by actions based on tag key-value pairs attached to the resource | String
aws:TagKeys | Filters access by actions based on the presence of tag keys in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.